==> win32_Release_v4.0.0_r923.zip: data/scripts/buildings/base_defense_building.lua <==
amta9  VS:W'H:NfA#V?S7^0W$
h	z@ac`mbu\c{i6[:T5R7El00>R'Fk}gvL O.Jazg8Z6Y:Qk
kGjhjcK+++!+M8V5A(G)	n<S6PyO*L)G4Qȼԙ>&+vR R3JjWwԶӤքߪħߪƲ{VƨܵզʫǦո`jǩܯJHO+[(xois
=iiዋ㓢9iiF惲vv\  )fH<9P>wf}& #
*N!+"_GHo|>_,IdxoU2W#ƫsxQvƳ?8>
yvt s[CABg`Haf`d&_g	lzp\23Z<녏upYiik@`QaQ}	*138kDw [Em?=1ӗԎձ,1551?#ҷֺΦ~vFf|~T+"?4+ϛ/;=!Ɣ\]sysz,Ӡոi	qY%$ԭkk<()LH:31C&U LdY0Vv\AJa̸vv509K.Z/]3;jkaѵ״ع6&>$
f`ͽܿԕ28].g|d[4U1]\{۾݁պʳz{S!D7eeJSrUơİԴipz)[8{zuaI`Nҷᕔݲ̠{g̓O*q⿟Ѹ,ñìͫ٭ #!o  N03_=%<@A`3CWt^~v'?:.{~ƶ-
b.+▾ݲܨɠΫՊm31220 &>?]cOoHxyxQ[QX02VRP6_8%I)G(\؜ij:vVzs_W/,	zZ$+uSoBKe`@%U0^:IaPX 6=Y)ZvcH+J)A$͠!IjJJ&/!L 6ݤ>/\9MjҌۯκϼlh@i֞ڮ̾۶ٯ<ᕃGO`vKҢ냄ϻϮͦ.-
dpe ȲG#lwT#kpRnMi}TvǷ󠀋!361<U3tuKkZ=d	y-ȿ֢ dsuYy^~w$Ij:
"  ci{~{z^YzS\Й̭ՑI{SZB,XxqYpYyVvGwW}]oƻ]ac/@'N-Mq[[dַ0'矁M=O&R7g{f`jgힰŵ4FҤͣRhbkb̕ʐ偐_qGPwݱ62}y]Y	e/٭򊊉ڹؾطba׺N_+,)WFo燝͵ضпmJPQ~v
(bJ◀~בb1̤šι33L^nN'XxEeM==DOa)+CcFgN`Gk#	Ƣ.Zp?녣_vX&>;+
yR>>սܯkkKAHRF`4AX[
dbo2!	#2;;R4})ynlL"M:Ƶ7&9tNi4=삠ɨeWstJ68 Xէ£ײGA@%Q$TvߧߧɡȻ3q9jmt%#L:_-_6R75GKk
d  C"N"qs6lni :^pa&G*O^vحȁBkfS2,%79:VEef(<ԸLx2㟁::3XibWwdfnN@*
*o{Uǯ\,hkjcu=9򾞙˧	|T1By$087t]-$|Nj '@%Qs201=qSHk[U$acCBfa"烇O6)imefPALtfk(˧}lHxGC0iyоba:33¡Ǣп{ln>Fgd'B,X=OodfpTX7=kqzs[-L U0EdOVe,,
)/'O.]lyjk+=?=?>ZDAmMolLM}~yx<Y4[7^-E蘓9=8LDE5T!RfJy[k˾ͨhaO$@SwφJNkˉ1<;OkHx_n5YY98ꖾU1_6ZZTp6յSϩ۴񖜕Tv.[y36-LbkM}Mk􈨁4@ԬƢq+㥅ߖYX(
aGkı,sWk/V*ǵ"PwjŔʱѴձ䲂һ['#P8W#p eGgPa9rU!!޿	jYξҳ蓍DjFN	'E1?$RR
l臎(T9uIm
E醯o)MVuҔrO$)gd%A%y)H$eMكqr]y8`cA-Ig'pFbQrPT4thgd̨ĝgg#~]($ʯƯi{P?M in,ZYyDoû!!
pΪ*mmgngE}VB3",--
 Ȕ|}TUToocCA/"3" 58),ቇAS;0Tyh
\~/ (wwvX5W'f⺟é7)7!u efL陉A@h_]ξn˃WumAC!	
'G̏ȡ̩.)ւTKK?:k͙%%!)#*?OFd2p9[yЮ9*$->E1__/\&$T' DDc	
(#,\\tWTvZzRbbE99="BTwU!8 #%!cN!U0]~6t~w}_58&S=H;^:ݮfC@-}Xt2..*RZiԬqjwjHxUp7_Cݻڬު.ɰѥї36R1``Pv#M$PpfdZ[v[{GfP{YxbOPsCbɮ˿ѥѾУͩŠDx]IyY~{nk)%qÜ쉮>=\(
ZmQz63&
+xZoA#P~c@ BfbR&/CCk茍ƨǰķfR
xdE!&Va5Yo⚟ uj08kXxPwaPQvVxV`Ȋx:ڿ#HnC
F!T3@bPӷش-)@&.g-(!+(][%YhXYcE|R0E9*$="r?c\퉚BkҬUhjid_fW3?>Z3@4C&;ið~7><jJgGdd7E)Qyȩͤ_]y) ) _]_q	)#
;;8		pZ<<El',@~[/ݯGWOJIkvwf41
X,CgOϷ"!,%LC`(	gkdCYZzFmX#*moӛμӣƴv?^-Hó 	 		%35-'14(hL5;h i`@%D'S:L-Y<6҄邈PG7|}XS8
$Zz|qgE|@
C`Xᕓ	
#Re˧ZZwೝt]zFEOqT򲒯85WWt<Ux (3_}9烦lNvX׷􉉧jL|#UiwmwZ:%	u 4858|||@Vم#prVnn0LMkꕖn'$(G)E<g>Jl$Mc##ϕtt\P@DT_>9@nNϼ޺-;K$We:9kkK@8?4],Y<u10v|vggg

==> win32_Release_v4.0.1_r945.zip: data/scripts/buildings/base_defense_building.lua <==
amta9  VS:W'H:NfA#V?S7^0W$
h	z@ac`mbu\c{i6[:T5R7El00>R'Fk}gvL O.Jazg8Z6Y:Qk
kGjhjcK+++!+M8V5A(G)	n<S6PyO*L)G4Qȼԙ>&+vR R3JjWwԶӤքߪħߪƲ{VƨܵզʫǦո`jǩܯJHO+[(xois
=iiዋ㓢9iiF惲vv\  )fH<9P>wf}& #
*N!+"_GHo|>_,IdxoU2W#ƫsxQvƳ?8>
yvt s[CABg`Haf`d&_g	lzp\23Z<녏upYiik@`QaQ}	*138kDw [Em?=1ӗԎձ,1551?#ҷֺΦ~vFf|~T+"?4+ϛ/;=!Ɣ\]sysz,Ӡոi	qY%$ԭkk<()LH:31C&U LdY0Vv\AJa̸vv509K.Z/]3;jkaѵ״ع6&>$
f`ͽܿԕ28].g|d[4U1]\{۾݁պʳz{S!D7eeJSrUơİԴipz)[8{zuaI`Nҷᕔݲ̠{g̓O*q⿟Ѹ,ñìͫ٭ #!o  N03_=%<@A`3CWt^~v'?:.{~ƶ-
b.+▾ݲܨɠΫՊm31220 &>?]cOoHxyxQ[QX02VRP6_8%I)G(\؜ij:vVzs_W/,	zZ$+uSoBKe`@%U0^:IaPX 6=Y)ZvcH+J)A$͠!IjJJ&/!L 6ݤ>/\9MjҌۯκϼlh@i֞ڮ̾۶ٯ<ᕃGO`vKҢ냄ϻϮͦ.-
dpe ȲG#lwT#kpRnMi}TvǷ󠀋!361<U3tuKkZ=d	y-ȿ֢ dsuYy^~w$Ij:
"  ci{~{z^YzS\Й̭ՑI{SZB,XxqYpYyVvGwW}]oƻ]ac/@'N-Mq[[dַ0'矁M=O&R7g{f`jgힰŵ4FҤͣRhbkb̕ʐ偐_qGPwݱ62}y]Y	e/٭򊊉ڹؾطba׺N_+,)WFo燝͵ضпmJPQ~v
(bJ◀~בb1̤šι33L^nN'XxEeM==DOa)+CcFgN`Gk#	Ƣ.Zp?녣_vX&>;+
yR>>սܯkkKAHRF`4AX[
dbo2!	#2;;R4})ynlL"M:Ƶ7&9tNi4=삠ɨeWstJ68 Xէ£ײGA@%Q$TvߧߧɡȻ3q9jmt%#L:_-_6R75GKk
d  C"N"qs6lni :^pa&G*O^vحȁBkfS2,%79:VEef(<ԸLx2㟁::3XibWwdfnN@*
*o{Uǯ\,hkjcu=9򾞙˧	|T1By$087t]-$|Nj '@%Qs201=qSHk[U$acCBfa"烇O6)imefPALtfk(˧}lHxGC0iyоba:33¡Ǣп{ln>Fgd'B,X=OodfpTX7=kqzs[-L U0EdOVe,,
)/'O.]lyjk+=?=?>ZDAmMolLM}~yx<Y4[7^-E蘓9=8LDE5T!RfJy[k˾ͨhaO$@SwφJNkˉ1<;OkHx_n5YY98ꖾU1_6ZZTp6յSϩ۴񖜕Tv.[y36-LbkM}Mk􈨁4@ԬƢq+㥅ߖYX(
aGkı,sWk/V*ǵ"PwjŔʱѴձ䲂һ['#P8W#p eGgPa9rU!!޿	jYξҳ蓍DjFN	'E1?$RR
l臎(T9uIm
E醯o)MVuҔrO$)gd%A%y)H$eMكqr]y8`cA-Ig'pFbQrPT4thgd̨ĝgg#~]($ʯƯi{P?M in,ZYyDoû!!
pΪ*mmgngE}VB3",--
 Ȕ|}TUToocCA/"3" 58),ቇAS;0Tyh
\~/ (wwvX5W'f⺟é7)7!u efL陉A@h_]ξn˃WumAC!	
'G̏ȡ̩.)ւTKK?:k͙%%!)#*?OFd2p9[yЮ9*$->E1__/\&$T' DDc	
(#,\\tWTvZzRbbE99="BTwU!8 #%!cN!U0]~6t~w}_58&S=H;^:ݮfC@-}Xt2..*RZiԬqjwjHxUp7_Cݻڬު.ɰѥї36R1``Pv#M$PpfdZ[v[{GfP{YxbOPsCbɮ˿ѥѾУͩŠDx]IyY~{nk)%qÜ쉮>=\(
ZmQz63&
+xZoA#P~c@ BfbR&/CCk茍ƨǰķfR
xdE!&Va5Yo⚟ uj0}gEIuҳФͻڮ:ia2Z3V:^~CcdFh?5<֒c~f%(O<zq덭̿+$T~WQ/hoHKzJKgZlB   'usP oM]bӷఙ􊃫'~us9?[WV2[(\7tTiIk򠈫+ھ	 ,T}QqCҫiK'K9׳O\f) ) _]_q	)#
;;8		pZ<<El',@~[sWށ#T7C*E+8)#*Ҵ$FA5߫=.μӣƴrO.]8߫۟Ϝ=HA!!2$
!+Ä
.x
oeT=u|rs_2,y{QqR.	+4{X_Wpge	j=$(*
y]%*Ǯ5y"/F- /!?'``INc;̪Ʃƴ 0FkJt003/?bF?8zn
"J+Oj\]ujx[0 oDxVqƻQwO:jVpi s^6(	JBCnCcNn***^w¯KImnn0@x%ݻǦ¦NW?v~Rrsf5A R&ڃ)[yMbE5! 7omF 4GD%A%߬,Ϧעǎ㇍
